@@ -44,6 +44,7 @@
 #include <QtGlobal>
 #include <QTimer>
 #include <QVBoxLayout>
+#include <QSvgWidget>
 #include "qtgui/ioconfig.h"
 #include "mainwindow.h"
 
@@ -83,7 +84,7 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     setWindowTitle(QString("Gqrx %1").arg(VERSION));
 
     /* frequency control widget */
-    ui->freqCtrl->setup(10, (quint64) 0, (quint64) 9999e6, 1, UNITS_MHZ);
+    ui->freqCtrl->setup(0, 0, 9999e6, 1, FCTL_UNIT_NONE);
     ui->freqCtrl->setFrequency(144500000);
 
     d_filter_shape = receiver::FILTER_SHAPE_NORMAL;
@@ -183,7 +184,9 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(ui->freqCtrl, SIGNAL(newFrequency(qint64)), this, SLOT(setNewFrequency(qint64)));
     connect(ui->freqCtrl, SIGNAL(newFrequency(qint64)), remote, SLOT(setNewFrequency(qint64)));
     connect(ui->freqCtrl, SIGNAL(newFrequency(qint64)), uiDockAudio, SLOT(setRxFrequency(qint64)));
+    connect(ui->freqCtrl, SIGNAL(newFrequency(qint64)), uiDockRxOpt, SLOT(setRxFreq(qint64)));
     connect(uiDockInputCtl, SIGNAL(lnbLoChanged(double)), this, SLOT(setLnbLo(double)));
+    connect(uiDockInputCtl, SIGNAL(lnbLoChanged(double)), remote, SLOT(setLnbLo(double)));
     connect(uiDockInputCtl, SIGNAL(gainChanged(QString, double)), this, SLOT(setGain(QString,double)));
     connect(uiDockInputCtl, SIGNAL(autoGainChanged(bool)), this, SLOT(setAutoGain(bool)));
     connect(uiDockInputCtl, SIGNAL(freqCorrChanged(double)), this, SLOT(setFreqCorr(double)));
@@ -192,6 +195,8 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(uiDockInputCtl, SIGNAL(iqBalanceChanged(bool)), this, SLOT(setIqBalance(bool)));
     connect(uiDockInputCtl, SIGNAL(ignoreLimitsChanged(bool)), this, SLOT(setIgnoreLimits(bool)));
     connect(uiDockInputCtl, SIGNAL(antennaSelected(QString)), this, SLOT(setAntenna(QString)));
+    connect(uiDockInputCtl, SIGNAL(freqCtrlResetChanged(bool)), this, SLOT(setFreqCtrlReset(bool)));
+    connect(uiDockRxOpt, SIGNAL(rxFreqChanged(qint64)), ui->freqCtrl, SLOT(setFrequency(qint64)));
     connect(uiDockRxOpt, SIGNAL(filterOffsetChanged(qint64)), this, SLOT(setFilterOffset(qint64)));
     connect(uiDockRxOpt, SIGNAL(filterOffsetChanged(qint64)), remote, SLOT(setFilterOffset(qint64)));
     connect(uiDockRxOpt, SIGNAL(demodSelected(int)), this, SLOT(selectDemod(int)));
@@ -221,6 +226,7 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(uiDockAudio, SIGNAL(fftRateChanged(int)), this, SLOT(setAudioFftRate(int)));
     connect(uiDockFft, SIGNAL(fftSizeChanged(int)), this, SLOT(setIqFftSize(int)));
     connect(uiDockFft, SIGNAL(fftRateChanged(int)), this, SLOT(setIqFftRate(int)));
+    connect(uiDockFft, SIGNAL(fftWindowChanged(int)), this, SLOT(setIqFftWindow(int)));
     connect(uiDockFft, SIGNAL(wfSpanChanged(quint64)), this, SLOT(setWfTimeSpan(quint64)));
     connect(uiDockFft, SIGNAL(fftSplitChanged(int)), this, SLOT(setIqFftSplit(int)));
     connect(uiDockFft, SIGNAL(fftAvgChanged(float)), this, SLOT(setIqFftAvg(float)));
@@ -235,6 +241,8 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
             ui->plotter, SLOT(setWaterfallRange(float,float)));
     connect(ui->plotter, SIGNAL(pandapterRangeChanged(float,float)),
             uiDockFft, SLOT(setPandapterRange(float,float)));
+    connect(ui->plotter, SIGNAL(newZoomLevel(float)),
+            uiDockFft, SLOT(setZoomLevel(float)));
 
     connect(uiDockFft, SIGNAL(fftColorChanged(QColor)), this, SLOT(setFftColor(QColor)));
     connect(uiDockFft, SIGNAL(fftFillToggled(bool)), this, SLOT(setFftFill(bool)));
@@ -258,6 +266,8 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(remote, SIGNAL(newFilterOffset(qint64)), this, SLOT(setFilterOffset(qint64)));
     connect(remote, SIGNAL(newFilterOffset(qint64)), uiDockRxOpt, SLOT(setFilterOffset(qint64)));
     connect(remote, SIGNAL(newFrequency(qint64)), ui->freqCtrl, SLOT(setFrequency(qint64)));
+    connect(remote, SIGNAL(newLnbLo(double)), uiDockInputCtl, SLOT(setLnbLo(double)));
+    connect(remote, SIGNAL(newLnbLo(double)), this, SLOT(setLnbLo(double)));
     connect(remote, SIGNAL(newMode(int)), this, SLOT(selectDemod(int)));
     connect(remote, SIGNAL(newMode(int)), uiDockRxOpt, SLOT(setCurrentDemod(int)));
     connect(remote, SIGNAL(newSquelchLevel(double)), this, SLOT(setSqlLevel(double)));
@@ -265,6 +275,8 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(uiDockRxOpt, SIGNAL(sqlLevelChanged(double)), remote, SLOT(setSquelchLevel(double)));
     connect(remote, SIGNAL(startAudioRecorderEvent()), uiDockAudio, SLOT(startAudioRecorder()));
     connect(remote, SIGNAL(stopAudioRecorderEvent()), uiDockAudio, SLOT(stopAudioRecorder()));
+    connect(ui->plotter, SIGNAL(newFilterFreq(int, int)), remote, SLOT(setPassband(int, int)));
+    connect(remote, SIGNAL(newPassband(int)), this, SLOT(setPassband(int)));
 
     rds_timer = new QTimer(this);
     connect(rds_timer, SIGNAL(timeout()), this, SLOT(rdsTimeout()));
@@ -308,7 +320,9 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
         {
             configOk = true;
         }
-   }
+    }
+
+    qsvg_dummy = new QSvgWidget();
 }
 
 MainWindow::~MainWindow()
@@ -363,6 +377,7 @@ MainWindow::~MainWindow()
     delete [] d_realFftData;
     delete [] d_iirFftData;
     delete [] d_pwrFftData;
+    delete qsvg_dummy;
 }
 
 /**
@@ -575,9 +590,30 @@ bool MainWindow::loadConfig(const QString cfgfile, bool check_crash,
         setNewFrequency(ui->freqCtrl->getFrequency()); // ensure all GUI and RF is updated
     }
 
-    remote->readSettings(m_settings);
+    {
+        int flo = m_settings->value("receiver/filter_low_cut", 0).toInt(&conv_ok);
+        int fhi = m_settings->value("receiver/filter_high_cut", 0).toInt(&conv_ok);
+
+        if (conv_ok && flo != fhi)
+        {
+            on_plotter_newFilterFreq(flo, fhi);
+        }
+    }
+
     iq_tool->readSettings(m_settings);
 
+    /*
+     * Initialization the remote control at the end.
+     * We must be sure that all variables initialized before starting RC server.
+     */
+    remote->readSettings(m_settings);
+    bool_val = m_settings->value("remote_control/enabled", false).toBool();
+    if (bool_val)
+    {
+       remote->start_server();
+       ui->actionRemoteControl->setChecked(true);
+    }
+
     return conf_ok;
 }
 
@@ -609,6 +645,11 @@ bool MainWindow::saveConfig(const QString cfgfile)
     else
         newfile = QString("%1/%2").arg(m_cfg_dir).arg(cfgfile);
 
+    if (newfile == oldfile) {
+        qDebug() << "New file is equal to old file => SYNCING...";
+        return true;
+    }
+
     if (QFile::exists(newfile))
     {
         qDebug() << "File" << newfile << "already exists => DELETING...";
@@ -652,6 +693,16 @@ void MainWindow::storeSession()
 
         remote->saveSettings(m_settings);
         iq_tool->saveSettings(m_settings);
+
+        {
+            int     flo, fhi;
+            ui->plotter->getHiLowCutFrequencies(&flo, &fhi);
+            if (flo != fhi)
+            {
+                m_settings->setValue("receiver/filter_low_cut", flo);
+                m_settings->setValue("receiver/filter_high_cut", fhi);
+            }
+        }
     }
 }
 
@@ -702,7 +753,8 @@ void MainWindow::updateFrequencyRange()
     qint64 start = (qint64)(rx->get_filter_offset()) + d_hw_freq_start + d_lnb_lo;
     qint64 stop  = (qint64)(rx->get_filter_offset()) + d_hw_freq_stop  + d_lnb_lo;
 
-    ui->freqCtrl->setup(10, start, stop, 1, UNITS_MHZ);
+    ui->freqCtrl->setup(0, start, stop, 1, FCTL_UNIT_NONE);
+    uiDockRxOpt->setRxFreqRange(start, stop);
 }
 
 /**
@@ -827,11 +879,8 @@ void MainWindow::setGain(QString name, double gain)
 void MainWindow::setAutoGain(bool enabled)
 {
     rx->set_auto_gain(enabled);
-
     if (!enabled)
-    {
-        uiDockInputCtl->restoreManualGains(m_settings);
-    }
+        uiDockInputCtl->restoreManualGains();
 }
 
 /**
@@ -893,6 +942,13 @@ void MainWindow::setIgnoreLimits(bool ignore_limits)
     setNewFrequency(freq);
 }
 
+
+/** Reset lower digits of main frequency control widget */
+void MainWindow::setFreqCtrlReset(bool enabled)
+{
+    ui->freqCtrl->setResetLowerDigits(enabled);
+}
+
 /**
  * @brief Select new demodulator.
  * @param demod New demodulator.
@@ -917,11 +973,10 @@ void MainWindow::selectDemod(QString strModulation)
  */
 void MainWindow::selectDemod(int mode_idx)
 {
-    double quad_rate;
-    double cwofs = 0.0;
-    float maxdev;
-    int filter_preset = uiDockRxOpt->currentFilter();
-    int flo=0, fhi=0, click_res=100;
+    double  cwofs = 0.0;
+    int     filter_preset = uiDockRxOpt->currentFilter();
+    int     flo=0, fhi=0, click_res=100;
+    bool    rds_enabled;
 
     // validate mode_idx
     if (mode_idx < DockRxOpt::MODE_OFF || mode_idx >= DockRxOpt::MODE_LAST)
@@ -934,9 +989,9 @@ void MainWindow::selectDemod(int mode_idx)
     uiDockRxOpt->getFilterPreset(mode_idx, filter_preset, &flo, &fhi);
     d_filter_shape = (receiver::filter_shape)uiDockRxOpt->currentFilterShape();
 
-    if (rx->is_rds_decoder_active())
+    rds_enabled = rx->is_rds_decoder_active();
+    if (rds_enabled)
         setRdsDecoder(false);
-
     uiDockRDS->setDisabled();
 
     switch (mode_idx) {
@@ -948,53 +1003,39 @@ void MainWindow::selectDemod(int mode_idx)
             stopAudioRec();
             uiDockAudio->setAudioRecButtonState(false);
         }
-
         rx->set_demod(receiver::RX_DEMOD_OFF);
         click_res = 1000;
         break;
 
     case DockRxOpt::MODE_RAW:
-        /* Raw I/Q */
+        /* Raw I/Q; max 96 ksps*/
         rx->set_demod(receiver::RX_DEMOD_NONE);
-        ui->plotter->setDemodRanges(-45000, -200, 200, 45000, true);
+        ui->plotter->setDemodRanges(-40000, -200, 200, 40000, true);
         uiDockAudio->setFftRange(0,24000);
         click_res = 100;
         break;
 
     case DockRxOpt::MODE_AM:
         rx->set_demod(receiver::RX_DEMOD_AM);
-        ui->plotter->setDemodRanges(-45000, -200, 200, 45000, true);
+        ui->plotter->setDemodRanges(-40000, -200, 200, 40000, true);
         uiDockAudio->setFftRange(0,6000);
         click_res = 100;
         break;
 
     case DockRxOpt::MODE_NFM:
+        ui->plotter->setDemodRanges(-40000, -1000, 1000, 40000, true);
+        uiDockAudio->setFftRange(0, 5000);
         rx->set_demod(receiver::RX_DEMOD_NFM);
+        rx->set_fm_maxdev(uiDockRxOpt->currentMaxdev());
+        rx->set_fm_deemph(uiDockRxOpt->currentEmph());
         click_res = 100;
-        maxdev = uiDockRxOpt->currentMaxdev();
-        if (maxdev < 20000.0)
-        {   /** FIXME **/
-            ui->plotter->setDemodRanges(-45000, -250, 250, 45000, true);
-            uiDockAudio->setFftRange(0,6000);
-        }
-        else
-        {
-            ui->plotter->setDemodRanges(-45000, -1000, 1000, 45000, true);
-            uiDockAudio->setFftRange(0,24000);
-        }
         break;
 
     case DockRxOpt::MODE_WFM_MONO:
     case DockRxOpt::MODE_WFM_STEREO:
     case DockRxOpt::MODE_WFM_STEREO_OIRT:
         /* Broadcast FM */
-        quad_rate = rx->get_input_rate();
-        if (quad_rate < 500.0e3)
-            ui->plotter->setDemodRanges(-quad_rate/2.0, -10000,
-                                        10000, quad_rate/2.0,
-                                        true);
-        else
-            ui->plotter->setDemodRanges(-250000, -10000, 10000, 250000, true);
+        ui->plotter->setDemodRanges(-120e3, -10000, 10000, 120e3, true);
         uiDockAudio->setFftRange(0,24000);  /** FIXME: get audio rate from rx **/
         click_res = 1000;
         if (mode_idx == DockRxOpt::MODE_WFM_MONO)
@@ -1005,6 +1046,8 @@ void MainWindow::selectDemod(int mode_idx)
             rx->set_demod(receiver::RX_DEMOD_WFM_S);
 
         uiDockRDS->setEnabled();
+        if (rds_enabled)
+            setRdsDecoder(true);
         break;
 
     case DockRxOpt::MODE_LSB:
@@ -1057,6 +1100,9 @@ void MainWindow::selectDemod(int mode_idx)
     rx->set_cw_offset(cwofs);
     rx->set_sql_level(uiDockRxOpt->currentSquelchLevel());
 
+    remote->setMode(mode_idx);
+    remote->setPassband(flo, fhi);
+
     d_have_audio = (mode_idx != DockRxOpt::MODE_OFF);
 
     uiDockRxOpt->setCurrentDemod(mode_idx);
@@ -1073,20 +1119,6 @@ void MainWindow::setFmMaxdev(float max_dev)
 
     /* receiver will check range */
     rx->set_fm_maxdev(max_dev);
-
-    /* update filter */
-    if (max_dev < 20000.0)
-    {
-        ui->plotter->setDemodRanges(-25000, -1000, 1000, 25000, true);
-        ui->plotter->setHiLowCutFrequencies(-5000, 5000);
-        rx->set_filter(-5000.0, 5000.0, d_filter_shape);
-    }
-    else
-    {
-        ui->plotter->setDemodRanges(-45000, -10000, 10000, 45000, true);
-        ui->plotter->setHiLowCutFrequencies(-35000, 35000);
-        rx->set_filter(-35000.0, 35000.0, d_filter_shape);
-    }
 }
 
 
@@ -1184,6 +1216,7 @@ void MainWindow::setNoiseBlanker(int nbid, bool on, float threshold)
 void MainWindow::setSqlLevel(double level_db)
 {
     rx->set_sql_level(level_db);
+    ui->sMeter->setSqlLevel(level_db);
 }
 
 /**
@@ -1193,6 +1226,9 @@ void MainWindow::setSqlLevel(double level_db)
 double MainWindow::setSqlLevelAuto()
 {
     double level = rx->get_signal_pwr(true) + 1.0;
+    if (level > -10.0)  // avoid 0 dBFS
+        level = uiDockRxOpt->getSqlLevel();
+
     setSqlLevel(level);
     return level;
 }
@@ -1458,7 +1494,7 @@ void MainWindow::startIqPlayback(const QString filename, float samprate)
     storeSession();
 
     int sri = (int)samprate;
-    QString devstr = QString("file=%1,rate=%2,throttle=true,repeat=false")
+    QString devstr = QString("file='%1',rate=%2,throttle=true,repeat=false")
             .arg(filename).arg(sri);
 
     qDebug() << __func__ << ":" << devstr;
@@ -1569,6 +1605,11 @@ void MainWindow::setIqFftRate(int fps)
         iq_fft_timer->setInterval(interval);
 }
 
+void MainWindow::setIqFftWindow(int type)
+{
+    rx->set_iq_fft_window(type);
+}
+
 /** Waterfall time span has changed. */
 void MainWindow::setWfTimeSpan(quint64 span_ms)
 {
@@ -1859,7 +1900,7 @@ void MainWindow::on_plotter_newDemodFreq(qint64 freq, qint64 delta)
         rx->reset_rds_parser();
 }
 
-/* CPlotter::NewfilterFreq() is emitted */
+/* CPlotter::NewfilterFreq() is emitted or bookmark activated */
 void MainWindow::on_plotter_newFilterFreq(int low, int high)
 {
     receiver::status retcode;
@@ -2041,7 +2082,34 @@ void MainWindow::onBookmarkActivated(qint64 freq, QString demod, int bandwidth)
     }
 
     on_plotter_newFilterFreq(lo, hi);
-    ui->plotter->setHiLowCutFrequencies(lo, hi);
+}
+
+void MainWindow::setPassband(int bandwidth)
+{
+    /* Check if filter is symmetric or not by checking the presets */
+    int mode = uiDockRxOpt->currentDemod();
+    int preset = uiDockRxOpt->currentFilterShape();
+
+    int lo, hi;
+    uiDockRxOpt->getFilterPreset(mode, preset, &lo, &hi);
+
+    if(lo + hi == 0)
+    {
+        lo = -bandwidth / 2;
+        hi =  bandwidth / 2;
+    }
+    else if(lo >= 0 && hi >= 0)
+    {
+        hi = lo + bandwidth;
+    }
+    else if(lo <= 0 && hi <= 0)
+    {
+        lo = hi - bandwidth;
+    }
+
+    remote->setPassband(lo, hi);
+
+    on_plotter_newFilterFreq(lo, hi);
 }
 
 /** Launch Gqrx google group website. */
@@ -2129,12 +2197,12 @@ void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About Gqrx"),
         tr("<p>This is Gqrx %1</p>"
-           "<p>Copyright (C) 2011-2016 Alexandru Csete & contributors.</p>"
+           "<p>Copyright (C) 2011-2018 Alexandru Csete & contributors.</p>"
            "<p>Gqrx is a software defined radio (SDR) receiver powered by "
            "<a href='http://www.gnuradio.org/'>GNU Radio</a> and the Qt toolkit. "
-           "<p>Gqrx uses the <a href='http://sdr.osmocom.org/trac/wiki/GrOsmoSDR'>GrOsmoSDR</a> "
+           "<p>Gqrx uses the <a href='https://osmocom.org/projects/sdr/wiki/GrOsmoSDR'>GrOsmoSDR</a> "
            "input source block and and works with any input device supported by it, including "
-           "Funcube Dongles, RTL-SDR, Airspy, HackRF, RFSpace, BladeRF and USRP receivers."
+           "Funcube Dongle, RTL-SDR, Airspy, HackRF, RFSpace, BladeRF and USRP receivers."
            "</p>"
            "<p>You can download the latest version from the "
            "<a href='http://gqrx.dk/'>Gqrx website</a>."
