@@ -31,6 +31,7 @@
 #include <QTimer>
 #include <QMessageBox>
 #include <QFileDialog>
+#include <QSvgWidget>
 
 #include "qtgui/dockrxopt.h"
 #include "qtgui/dockaudio.h"
@@ -118,6 +119,9 @@ private:
 
     std::map<QString, QVariant> devList;
 
+    // dummy widget to enforce linking to QtSvg
+    QSvgWidget      *qsvg_dummy;
+
 private:
     void updateHWFrequencyRange(bool ignore_limits);
     void updateFrequencyRange();
@@ -139,6 +143,7 @@ private slots:
     void setDcCancel(bool enabled);
     void setIqBalance(bool enabled);
     void setIgnoreLimits(bool ignore_limits);
+    void setFreqCtrlReset(bool enabled);
     void selectDemod(QString demod);
     void selectDemod(int index);
     void setFmMaxdev(float max_dev);
@@ -155,6 +160,7 @@ private slots:
     void setSqlLevel(double level_db);
     double setSqlLevelAuto();
     void setAudioGain(float gain);
+    void setPassband(int bandwidth);
 
     /* audio recording and playback */
     void startAudioRec(const QString filename);
@@ -175,6 +181,7 @@ private slots:
     /* FFT settings */
     void setIqFftSize(int size);
     void setIqFftRate(int fps);
+    void setIqFftWindow(int type);
     void setIqFftSplit(int pct_wf);
     void setIqFftAvg(float avg);
     void setAudioFftRate(int fps);
