@@ -123,9 +123,9 @@ receiver::receiver(const std::string input_device,
 
     iq_swap = make_iq_swap_cc(false);
     dc_corr = make_dc_corr_cc(d_quad_rate, 1.0);
-    iq_fft = make_rx_fft_c(8192u, 0);
+    iq_fft = make_rx_fft_c(8192u, gr::filter::firdes::WIN_HANN);
 
-    audio_fft = make_rx_fft_f(8192u);
+    audio_fft = make_rx_fft_f(8192u, gr::filter::firdes::WIN_HANN);
     audio_gain0 = gr::blocks::multiply_const_ff::make(0.1);
     audio_gain1 = gr::blocks::multiply_const_ff::make(0.1);
 
@@ -272,8 +272,11 @@ void receiver::set_output_device(const std::string device)
 
     tb->lock();
 
-    tb->disconnect(audio_gain0, 0, audio_snk, 0);
-    tb->disconnect(audio_gain1, 0, audio_snk, 1);
+    if (d_demod != RX_DEMOD_OFF)
+    {
+        tb->disconnect(audio_gain0, 0, audio_snk, 0);
+        tb->disconnect(audio_gain1, 0, audio_snk, 1);
+    }
     audio_snk.reset();
 
 #ifdef WITH_PULSEAUDIO
@@ -284,8 +287,11 @@ void receiver::set_output_device(const std::string device)
     audio_snk = gr::audio::sink::make(d_audio_rate, device, true);
 #endif
 
-    tb->connect(audio_gain0, 0, audio_snk, 0);
-    tb->connect(audio_gain1, 0, audio_snk, 1);
+    if (d_demod != RX_DEMOD_OFF)
+    {
+        tb->connect(audio_gain0, 0, audio_snk, 0);
+        tb->connect(audio_gain1, 0, audio_snk, 1);
+    }
 
     tb->unlock();
 }
@@ -348,13 +354,6 @@ double receiver::set_input_rate(double rate)
     return d_input_rate;
 }
 
-
-/** Get current input sample rate. */
-double receiver::get_input_rate(void) const
-{
-    return d_input_rate;
-}
-
 /** Set input decimation */
 unsigned int receiver::set_input_decim(unsigned int decim)
 {
@@ -726,6 +725,11 @@ void receiver::set_iq_fft_size(int newsize)
     iq_fft->set_fft_size(newsize);
 }
 
+void receiver::set_iq_fft_window(int window_type)
+{
+    iq_fft->set_window_type(window_type);
+}
+
 /** Get latest baseband FFT data. */
 void receiver::get_iq_fft_data(std::complex<float>* fftPoints, unsigned int &fftsize)
 {
