@@ -119,11 +119,15 @@ public:
     void        set_antenna(const std::string &antenna);
 
     double      set_input_rate(double rate);
-    double      get_input_rate(void) const;
+    double      get_input_rate(void) const { return d_input_rate; }
 
     unsigned int    set_input_decim(unsigned int decim);
     unsigned int    get_input_decim(void) const { return d_decim; }
 
+    double      get_quad_rate(void) const {
+        return d_input_rate / (double)d_decim;
+    }
+
     double      set_analog_bandwidth(double bw);
     double      get_analog_bandwidth(void) const;
 
@@ -155,6 +159,7 @@ public:
     status      set_freq_corr(double ppm);
     float       get_signal_pwr(bool dbfs) const;
     void        set_iq_fft_size(int newsize);
+    void        set_iq_fft_window(int window_type);
     void        get_iq_fft_data(std::complex<float>* fftPoints,
                                 unsigned int &fftsize);
     void        get_audio_fft_data(std::complex<float>* fftPoints,
