@@ -72,10 +72,6 @@ void DockInputCtl::readSettings(QSettings * settings)
     setIgnoreLimits(bool_val);
     emit ignoreLimitsChanged(bool_val);
 
-    bool_val = settings->value("input/hwagc", false).toBool();
-    setAgc(bool_val);
-    emit autoGainChanged(bool_val);
-
     // Ignore antenna selection if there is only one option
     if (ui->antSelector->count() > 1)
     {
@@ -104,6 +100,15 @@ void DockInputCtl::readSettings(QSettings * settings)
             emit gainChanged(gain_name, gain_value);
         }
     }
+
+    bool_val = settings->value("input/hwagc", false).toBool();
+    setAgc(bool_val);
+    emit autoGainChanged(bool_val);
+
+    // misc GUI settings
+    bool_val = settings->value("gui/fctl_reset_digits", true).toBool();
+    emit freqCtrlResetChanged(bool_val);
+    ui->freqCtrlResetButton->setChecked(bool_val);
 }
 
 void DockInputCtl::saveSettings(QSettings * settings)
@@ -159,6 +164,12 @@ void DockInputCtl::saveSettings(QSettings * settings)
         settings->setValue("input/antenna", ui->antSelector->currentText());
     else
         settings->remove("input/antenna");
+
+    // Remember state of freqReset button. Default is checked.
+    if (!ui->freqCtrlResetButton->isChecked())
+        settings->setValue("gui/fctl_reset_digits", false);
+    else
+        settings->remove("gui/fctl_reset_digits");
 }
 
 void DockInputCtl::readLnbLoFromSettings(QSettings * settings)
@@ -325,6 +336,12 @@ void DockInputCtl::setAntenna(const QString &antenna)
         ui->antSelector->setCurrentIndex(index);
 }
 
+/** Enable/disable resetting lower digits on freqCtrl widgets */
+void DockInputCtl::setFreqCtrlReset(bool enabled)
+{
+    ui->freqCtrlResetButton->setChecked(enabled);
+}
+
 /**
  * Set gain stages.
  * @param gain_list A list containing the gain stages for this device.
@@ -346,16 +363,16 @@ void DockInputCtl::setGainStages(gain_list_t &gain_list)
         step  = (int)(10.0 * gain_list[i].step);
         gain  = (int)(10.0 * gain_list[i].value);
 
-        label = new QLabel(QString("%1 gain").arg(gain_list[i].name.c_str()), this);
-        label->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum));
+        label = new QLabel(QString("%1 ").arg(gain_list[i].name.c_str()), this);
+        label->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
 
-        value = new QLabel(QString("%1 dB").arg(gain_list[i].value, 0, 'f', 1), this);
-        value->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum));
+        value = new QLabel(QString(" %1 dB").arg(gain_list[i].value, 0, 'f', 1), this);
+        value->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
 
         slider = new QSlider(Qt::Horizontal, this);
         slider->setProperty("idx", i);
         slider->setProperty("name", QString(gain_list[i].name.c_str()));
-        slider->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum));
+        slider->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
         slider->setRange(start, stop);
         slider->setSingleStep(step);
         slider->setValue(gain);
@@ -363,7 +380,7 @@ void DockInputCtl::setGainStages(gain_list_t &gain_list)
             slider->setPageStep(10 * step);
 
         gainLayout->addWidget(label, i, 0, Qt::AlignLeft);
-        gainLayout->addWidget(slider, i, 1, Qt::AlignCenter);
+        gainLayout->addWidget(slider, i, 1);        // setting alignment would force minimum size
         gainLayout->addWidget(value, i, 2, Qt::AlignLeft);
 
         gain_labels.push_back(label);
@@ -391,27 +408,17 @@ void DockInputCtl::setGainStages(gain_list_t &gain_list)
  * Can be used for restoring the manual gains after auto-gain has been
  * disabled.
  */
-void DockInputCtl::restoreManualGains(QSettings *settings)
+void DockInputCtl::restoreManualGains(void)
 {
-    // gains are stored as a QMap<QString, QVariant(int)>
-    // note that we store the integer values, i.e. dB*10
-    QMap <QString, QVariant> allgains;
-    QString gain_name;
-    double gain_value;
-    if (settings->contains("input/gains"))
+    QString gain_stage;
+    double  gain_value;
+    int     i;
+
+    for (i = 0; i < gain_sliders.length(); i++)
     {
-        allgains = settings->value("input/gains").toMap();
-        QMapIterator <QString, QVariant> gain_iter(allgains);
-
-        while (gain_iter.hasNext())
-        {
-            gain_iter.next();
-
-            gain_name = gain_iter.key();
-            gain_value = 0.1 * (double)(gain_iter.value().toInt());
-            setGain(gain_name, gain_value);
-            emit gainChanged(gain_name, gain_value);
-        }
+        gain_stage = gain_sliders.at(i)->property("name").toString();
+        gain_value = 0.1 * (double)gain_sliders.at(i)->value();
+        emit gainChanged(gain_stage, gain_value);
     }
 }
 
@@ -484,6 +491,12 @@ void DockInputCtl::on_antSelector_currentIndexChanged(const QString &antenna)
     emit antennaSelected(antenna);
 }
 
+/** Reset box has changed */
+void DockInputCtl::on_freqCtrlResetButton_toggled(bool checked)
+{
+    emit freqCtrlResetChanged(checked);
+}
+
 /** Remove all widgets from the lists. */
 void DockInputCtl::clearWidgets()
 {
