@@ -771,6 +771,7 @@ void CPlotter::zoomStepX(float step, int x)
     setSpanFreq((quint32)new_range);
 
     float factor = (float)m_SampleFreq / (float)m_Span;
+    emit newZoomLevel(factor);
     qDebug() << QString("Spectrum zoom: %1x").arg(factor, 0, 'f', 1);
 
     m_PeakHoldValid = false;
@@ -1335,8 +1336,11 @@ void CPlotter::drawOverlay()
 #endif
 
             int level = 0;
-            for (; level < nLevels && tagEnd[level] > x; level++);
-                level %= nLevels;
+            while(level < nLevels && tagEnd[level] > x)
+                level++;
+            
+            if(level == nLevels)
+                level = 0;
 
             tagEnd[level] = x + nameWidth + slant - 1;
             m_BookmarkTags.append(qMakePair<QRect, qint64>(QRect(x, level * levelHeight, nameWidth + slant, fontHeight), bookmarks[i].frequency));
